/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-icon-view-win
 * @short_description: Window containing a #KibaIconView instance.
 * @see_also:#KibaIconView
 *
 * Window containing a #KibaIconView instance.
 */

#ifndef __KIBA_ICON_VIEW_WIN_H__
#define __KIBA_ICON_VIEW_WIN_H__

#include <gtk/gtk.h>
#include <kiba-icon-view.h>
#include <kiba-info-win.h>

G_BEGIN_DECLS

#define KIBA_TYPE_ICON_VIEW_WIN           (kiba_icon_view_win_get_type ())
#define KIBA_ICON_VIEW_WIN(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_ICON_VIEW_WIN, KibaIconViewWin))
#define KIBA_ICON_VIEW_WIN_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_ICON_VIEW_WIN,  KibaIconViewWinClass))
#define KIBA_IS_ICON_VIEW_WIN(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_ICON_VIEW_WIN))
#define KIBA_IS_ICON_VIEW_WIN_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_ICON_VIEW_WIN))
#define KIBA_ICON_VIEW_WIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_ICON_VIEW_WIN, KibaIconViewWinClass))

typedef struct _KibaIconViewWin       KibaIconViewWin;
typedef struct _KibaIconViewWinClass  KibaIconViewWinClass;

typedef enum {
	KIBA_ICON_VIEW_SCROLL_UP = -1,
	KIBA_ICON_VIEW_SCROLL_DOWN = 1
}KibaIconViewScrollState;

typedef enum {
	KIBA_ICON_VIEW_BOX_POSITION_RIGHT = 0,
	KIBA_ICON_VIEW_BOX_POSITION_LEFT,
}KibaIconViewBoxPosition;

struct _KibaIconViewWin {
	GObjectClass parent_instance;

	GtkWidget *win;
	GtkWidget *icon_view;
	GtkWidget *button_box;

	// boxes for custom widgets
	GtkWidget *top_box;
	GtkWidget *bottom_box;
	GtkWidget *right_box;
	
	// number of rows in the grid
	gint rows;
};

struct _KibaIconViewWinClass {
	GObjectClass  parent_class;
};

KibaIconViewWin*
kiba_icon_view_win_new (KibaIconViewBoxPosition position,
		gint columns,
		gint rows,
		gboolean close_button,
		gboolean use_scrolled_window,
		gboolean attached);

void
kiba_icon_view_win_add (KibaIconViewWin *view_win,
		GtkWidget *widget);

void
kiba_icon_view_win_remove (KibaIconViewWin *view_win,
		GtkWidget *widget);

G_END_DECLS

#endif
