/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-icon
 * @short_description: Icon object on #KibaDock.
 * @see_also:#KibaWin,#KibaDock
 *
 * Icon object on #KibaDock.
 */

#ifndef __KIBA_ICON_H__
#define __KIBA_ICON_H__

#include <glib.h>
#include <librsvg/rsvg.h>

#include <kiba-drawable-object.h>
#include <kiba-cached-icon.h>

G_BEGIN_DECLS

typedef struct _KibaIcon KibaIcon;
typedef struct _KibaIconClass KibaIconClass;

#define KIBA_TYPE_ICON           (kiba_icon_get_type ())
#define KIBA_ICON(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_ICON, KibaIcon))
#define KIBA_ICON_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TYPE_ICON,  KibaIconClass))
#define KIBA_IS_ICON(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_ICON))
#define KIBA_IS_ICON_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_ICON))
#define KIBA_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_ICON, KibaIconClass))

struct _KibaIcon {
	KibaDrawableObject parent;
	
	KibaCachedIcon *cached_icon;
	
	gchar *file;
	
	gint surface_height;
	gint surface_width;
	gint rotate_angle;
	
	GdkPixbuf *custom_pixbuf;
};

struct _KibaIconClass {
	KibaDrawableObjectClass parent_class;
};

gboolean kiba_icon_set_file (KibaIcon *icon,
                             const gchar *file);

GtkWidget*
kiba_icon_new (const gchar *object_id,
		gfloat scale_x, gfloat scale_y);

GtkWidget*
kiba_icon_new_from_file (const gchar *object_id,
		gfloat scale_x, gfloat scale_y,
		const gchar *file);

const char* kiba_icon_get_file (KibaIcon  *icon);

G_END_DECLS

#endif
