/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-image
 * @short_description: Widget showing an image.
 * @see_also:
 *
 * #KibaImage uses a cairo surface buffer to render an image.
 */

#ifndef __KIBA_IMAGE_H__
#define __KIBA_IMAGE_H__

#include <gtk/gtk.h>
#include <cairo.h>
#include <librsvg/rsvg.h>

G_BEGIN_DECLS

#define KIBA_TYPE_IMAGE           (kiba_image_get_type ())
#define KIBA_IMAGE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_IMAGE, KibaImage))
#define KIBA_IMAGE_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_IMAGE,  KibaImageClass))
#define KIBA_IS_IMAGE(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_IMAGE))
#define KIBA_IS_IMAGE_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_IMAGE))
#define KIBA_IMAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_IMAGE, KibaImageClass))

typedef struct _KibaImage       KibaImage;
typedef struct _KibaImageClass  KibaImageClass;

typedef enum {
	KIBA_IMAGE_STATE_SELECTED = 0,
	KIBA_IMAGE_STATE_NONE
}KibaImageState;

struct _KibaImage {
	GtkWidget widget;
	// The image surface
	cairo_surface_t *surface;
	// The surface width
	gint surface_width;
	// The surface height
	gint surface_height;
	// The image state
	KibaImageState state;
	// The image alpha
	gfloat alpha;
	
	RsvgHandle *handle;
	RsvgDimensionData svg_dimension_data;
	GdkPixbuf *pixbuf;
	gchar *icon;
};

struct _KibaImageClass {
	GtkWidgetClass  parent_class;
};

GtkWidget* kiba_image_new (void);

void
kiba_image_set_surface (KibaImage *image,
		cairo_surface_t *surface,
		gint width,
		gint height);
void
kiba_image_set_icon (KibaImage *image,
		const gchar* icon,
		gint width,
		gint height);

void
kiba_image_set_pixbuf (KibaImage  *image,
		GdkPixbuf *pixbuf,
		gint width,
		gint height);
void
kiba_image_set_svg_handle (KibaImage  *image,
		RsvgHandle *handle,
		gint width,
		gint height);

void
kiba_image_set_size (KibaImage *image,
		gint width,
		gint height);

void
kiba_image_set_alpha (KibaImage *image,
		gfloat  alpha);

float
kiba_image_get_alpha (KibaImage *image);

void
kiba_image_select (KibaImage *image,
		gboolean select);

gboolean
kiba_image_is_selected (KibaImage *image);

gboolean
kiba_image_draw(KibaImage *image, cairo_t *cr);

G_END_DECLS

#endif
