/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * SECTION:kiba-transparent-window
 * @short_description: Window with transparent background.
 * @stability: Unstable
 *
 * Window with transparent background.
 * If a composite manager is running real transparency is used,
 * else the window is set keep below and fake transparency is used.
 */

#ifndef __KIBA_TRANSPARENT_WINDOW_H__
#define __KIBA_TRANSPARENT_WINDOW_H__

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <cairo.h>

G_BEGIN_DECLS

#define KIBA_TYPE_TRANSPARENT_WINDOW           (kiba_transparent_window_get_type ())
#define KIBA_TRANSPARENT_WINDOW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_TRANSPARENT_WINDOW, KibaTransparentWindow))
#define KIBA_TRANSPARENT_WINDOW_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TRANSPARENT_WINDOW,  KibaTransparentWindowClass))
#define KIBA_IS_TRANSPARENT_WINDOW(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_TRANSPARENT_WINDOW))
#define KIBA_IS_TRANSPARENT_WINDOW_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_TRANSPARENT_WINDOW))
#define KIBA_TRANSPARENT_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_TRANSPARENT_WINDOW, KibaTransparentWindowClass))

typedef struct _KibaTransparentWindow KibaTransparentWindow;
typedef struct _KibaTransparentWindowClass KibaTransparentWindowClass;

struct _KibaTransparentWindow {
	GtkWindow window;
	
	GdkPixbuf *desktop_background;
};

struct _KibaTransparentWindowClass {
	GtkWindowClass  parent_class;
};

GtkWidget*
kiba_transparent_window_new ();

void
kiba_transparent_window_draw_background (KibaTransparentWindow *win, cairo_t *cr);

gboolean
kiba_transparent_window_is_composited (KibaTransparentWindow *win);

G_END_DECLS

#endif
